@@ -1,7 +1,7 @@
 #  Authors: Sylvain Marie <sylvain.marie@se.com>
 #
 #  Copyright (c) Schneider Electric Industries, 2019. All right reserved.
-from pyfields import field, init_fields
+from pyfields import field, init_fields, autofields
 
 
 def test_issue_51():
@@ -13,3 +13,15 @@ def test_issue_51():
             pass
 
     return A
+
+
+def test_issue_67():
+    @autofields
+    class Frog:
+        another: int = 1
+
+        @property
+        def balh(self):
+            print('asd')
+
+    return Frog
